@@ -21,14 +21,65 @@
 #include "H5PropList.h"
 #include "H5FaccProp.h"
 
-#ifndef H5_NO_NAMESPACE
 namespace H5 {
-#endif
+
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
+// This DOXYGEN_SHOULD_SKIP_THIS block is a work-around approach to control
+// the order of creation and deletion of the global constants.  See Design Notes
+// in "H5PredType.cpp" for information.
+
+// Initialize a pointer for the constant
+FileAccPropList* FileAccPropList::DEFAULT_ = 0;
 
 //--------------------------------------------------------------------------
-///\brief	Constant for default property
+// Function:    FileAccPropList::getConstant
+//              Creates a FileAccPropList object representing the HDF5 constant
+//              H5P_FILE_ACCESS, pointed to by FileAccPropList::DEFAULT_
+// exception    H5::PropListIException
+// Description
+//              If FileAccPropList::DEFAULT_ already points to an allocated
+//              object, throw a PropListIException.  This scenario should not
+//              happen.
+// Programmer   Binh-Minh Ribler - 2015
 //--------------------------------------------------------------------------
-const FileAccPropList FileAccPropList::DEFAULT;
+FileAccPropList* FileAccPropList::getConstant()
+{
+    // Tell the C library not to clean up, H5Library::termH5cpp will call
+    // H5close - more dependency if use H5Library::dontAtExit()
+    if (!IdComponent::H5dontAtexit_called)
+    {
+        (void) H5dont_atexit();
+        IdComponent::H5dontAtexit_called = true;
+    }
+
+    // If the constant pointer is not allocated, allocate it. Otherwise,
+    // throw because it shouldn't be.
+    if (DEFAULT_ == 0)
+        DEFAULT_ = new FileAccPropList(H5P_FILE_ACCESS);
+    else
+        throw PropListIException("FileAccPropList::getConstant", "FileAccPropList::getConstant is being invoked on an allocated DEFAULT_");
+    return(DEFAULT_);
+}
+
+//--------------------------------------------------------------------------
+// Function:    FileAccPropList::deleteConstants
+// Purpose:     Deletes the constant object that FileAccPropList::DEFAULT_
+//              points to.
+// exception    H5::PropListIException
+// Programmer   Binh-Minh Ribler - 2015
+//--------------------------------------------------------------------------
+void FileAccPropList::deleteConstants()
+{
+    if (DEFAULT_ != 0)
+        delete DEFAULT_;
+}
+
+//--------------------------------------------------------------------------
+// Purpose:	Constant for default property
+//--------------------------------------------------------------------------
+const FileAccPropList& FileAccPropList::DEFAULT = *getConstant();
+
+#endif // DOXYGEN_SHOULD_SKIP_THIS
 
 //--------------------------------------------------------------------------
 // Function:	Default Constructor
@@ -263,6 +314,8 @@ FileAccPropList FileAccPropList::getFamily(hsize_t& memb_size) const
 ///		Temporary - For information, please refer to:
 /// http://www.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetFaplSplit
 // Programmer:  Binh-Minh Ribler - April, 2004
+// Modification
+//		Replaced the version without const parameter - Apr, 2014
 //--------------------------------------------------------------------------
 void FileAccPropList::setSplit(const FileAccPropList& meta_plist, const FileAccPropList& raw_plist, const char* meta_ext, const char* raw_ext ) const
 {
@@ -275,24 +328,6 @@ void FileAccPropList::setSplit(const FileAccPropList& meta_plist, const FileAccP
    }
 }
 
-//--------------------------------------------------------------------------
-// Function:	FileAccPropList::setSplit
-///\brief	This is an overloaded member function, kept for backward
-///		compatibility.  It differs from the above function in that it
-///		misses const's.  This wrapper will be removed in future release.
-///\param	meta_plist  - IN: File access plist for the metadata file
-///\param	raw_plist   - IN: File access plist for the raw data file
-///\param	meta_ext    - IN: Metadata filename extension as \c char*
-///\param	raw_ext     - IN: Raw data filename extension as \c char*
-///\exception	H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
-// Note:	Retiring April, 2014
-//--------------------------------------------------------------------------
-void FileAccPropList::setSplit(FileAccPropList& meta_plist, FileAccPropList& raw_plist, const char* meta_ext, const char* raw_ext ) const
-{
-    setSplit((const FileAccPropList)meta_plist, (const FileAccPropList)raw_plist, meta_ext, raw_ext);
-}
-
 //--------------------------------------------------------------------------
 // Function:	FileAccPropList::setSplit
 ///\brief	This is an overloaded member function, provided for convenience.
@@ -303,30 +338,14 @@ void FileAccPropList::setSplit(FileAccPropList& meta_plist, FileAccPropList& raw
 ///\param	raw_ext     - IN: Raw data filename extension as \c H5std_string
 ///\exception	H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
+// Modification
+//		Replaced the version without const parameter - Apr, 2014
 //--------------------------------------------------------------------------
 void FileAccPropList::setSplit(const FileAccPropList& meta_plist, const FileAccPropList& raw_plist, const H5std_string& meta_ext, const H5std_string& raw_ext ) const
 {
    setSplit( meta_plist, raw_plist, meta_ext.c_str(), raw_ext.c_str() );
 }
 
-//--------------------------------------------------------------------------
-// Function:	FileAccPropList::setSplit
-///\brief	This is an overloaded member function, kept for backward
-///		compatibility.  It differs from the above function in that it
-///		misses const's.  This wrapper will be removed in future release.
-///\param	meta_plist  - IN: File access plist for the metadata file
-///\param	raw_plist   - IN: File access plist for the raw data file
-///\param	meta_ext    - IN: Metadata filename extension as \c string
-///\param	raw_ext     - IN: Raw data filename extension as \c string
-///\exception	H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
-// Note:	Retiring April, 2014
-//--------------------------------------------------------------------------
-void FileAccPropList::setSplit(FileAccPropList& meta_plist, FileAccPropList& raw_plist, const H5std_string& meta_ext, const H5std_string& raw_ext ) const
-{
-   setSplit((const FileAccPropList)meta_plist, (const FileAccPropList)raw_plist, meta_ext.c_str(), raw_ext.c_str() );
-}
-
 // Stream Virtual File Driver had been removed from the main library.
 // FileAccPropList::[s,g]etStream are now removed from the C++ API.
 // -BMR, March, 2012
@@ -596,7 +615,7 @@ void FileAccPropList::getCache( int& mdc_nelmts, size_t& rdcc_nelmts, size_t& rd
 ///\exception	H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void FileAccPropList::setFcloseDegree(H5F_close_degree_t degree)
+void FileAccPropList::setFcloseDegree(H5F_close_degree_t degree) const
 {
    herr_t ret_value = H5Pset_fclose_degree(id, degree);
    if( ret_value < 0 )
@@ -612,7 +631,7 @@ void FileAccPropList::setFcloseDegree(H5F_close_degree_t degree)
 ///\exception	H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-H5F_close_degree_t FileAccPropList::getFcloseDegree()
+H5F_close_degree_t FileAccPropList::getFcloseDegree() const
 {
    H5F_close_degree_t degree;
    herr_t ret_value = H5Pget_fclose_degree(id, &degree);
@@ -731,6 +750,4 @@ void FileAccPropList::getLibverBounds(H5F_libver_t& libver_low, H5F_libver_t& li
 //--------------------------------------------------------------------------
 FileAccPropList::~FileAccPropList() {}
 
-#ifndef H5_NO_NAMESPACE
 } // end namespace
-#endif
