@@ -21,6 +21,7 @@
 #include "H5PropList.h"
 #include "H5Location.h"
 #include "H5Object.h"
+#include "H5OcreatProp.h"
 #include "H5DcreatProp.h"
 #include "H5DxferProp.h"
 #include "H5FaccProp.h"
@@ -33,13 +34,8 @@
 #include "H5DataSet.h"
 #include "H5Attribute.h"
 #include "H5private.h"		// for HDmemset
-#include <iostream>
-using namespace std;
 
-
-#ifndef H5_NO_NAMESPACE
 namespace H5 {
-#endif
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 // userAttrOpWrpr simply interfaces between the user's function and the
@@ -76,8 +72,9 @@ H5Location::H5Location() : IdComponent() {}
 // been moved to the sub-classes.  It will be removed in 1.10 release.  If its
 // removal does not raise any problems in 1.10, it will be removed from 1.8 in
 // subsequent releases.
+// Removed in 1.10.1 - Aug 2016
 //--------------------------------------------------------------------------
-H5Location::H5Location(const hid_t object_id) : IdComponent() {}
+// H5Location::H5Location(const hid_t object_id) : IdComponent() {}
 
 //--------------------------------------------------------------------------
 // Function:	H5Location copy constructor
@@ -192,7 +189,7 @@ Attribute H5Location::openAttribute( const H5std_string& name ) const
 Attribute H5Location::openAttribute( const unsigned int idx ) const
 {
    hid_t attr_id = H5Aopen_by_idx(getId(), ".", H5_INDEX_CRT_ORDER,
-			H5_ITER_INC, (hsize_t)idx, H5P_DEFAULT, H5P_DEFAULT);
+		H5_ITER_INC, static_cast<hsize_t>(idx), H5P_DEFAULT, H5P_DEFAULT);
    if( attr_id > 0 )
    {
 	Attribute attr;
@@ -232,9 +229,9 @@ int H5Location::iterateAttrs( attr_operator_t user_op, unsigned *_idx, void *op_
    userData->location = this;
 
    // call the C library routine H5Aiterate2 to iterate the attributes
-   hsize_t idx = _idx ? (hsize_t)*_idx : 0;
+   hsize_t idx = _idx ? static_cast<hsize_t>(*_idx) : 0;
    int ret_value = H5Aiterate2(getId(), H5_INDEX_NAME, H5_ITER_INC, &idx,
-			userAttrOpWrpr, (void *) userData);
+			userAttrOpWrpr, static_cast<void *>(userData));
 
    // release memory
    delete userData;
@@ -242,7 +239,7 @@ int H5Location::iterateAttrs( attr_operator_t user_op, unsigned *_idx, void *op_
    if( ret_value >= 0 ) {
       /* Pass back update index value to calling code */
       if (_idx)
-	 *_idx = (unsigned)idx;
+	 *_idx = static_cast<unsigned>(idx);
 
       return( ret_value );
    }
@@ -264,7 +261,7 @@ int H5Location::getNumAttrs() const
    if(H5Oget_info(getId(), &oinfo) < 0)
       throw AttributeIException(inMemFunc("getNumAttrs"), "H5Oget_info failed");
    else
-      return( (int)oinfo.num_attrs );
+      return(static_cast<int>(oinfo.num_attrs));
 }
 
 //--------------------------------------------------------------------------
@@ -389,7 +386,7 @@ H5std_string H5Location::getFileName() const
    try {
       return(p_get_file_name());
    }
-   catch (LocationException E) {
+   catch (LocationException& E) {
       throw FileIException(inMemFunc("getFileName"), E.getDetailMsg());
    }
 }
@@ -519,7 +516,7 @@ ssize_t H5Location::getComment(const char* name, size_t buf_size, char* comment)
     }
     // If the comment is longer than the provided buffer size, the C library
     // will not null terminate it
-    if ((size_t)comment_len >= buf_size)
+    if (static_cast<size_t>(comment_len) >= buf_size)
 	comment[buf_size-1] = '\0';
 
     // Return the actual comment length, which might be different from buf_size
@@ -565,8 +562,8 @@ H5std_string H5Location::getComment(const char* name, size_t buf_size) const
 	HDmemset(comment_C, 0, tmp_len+1); // clear buffer
 
 	// Used overloaded function
-	ssize_t comment_len = getComment(name, tmp_len+1, comment_C);
-	if (comment_len < 0)
+	ssize_t temp_len = getComment(name, tmp_len+1, comment_C);
+	if (temp_len < 0)
 	{
 	    delete []comment_C;
 	    throw LocationException("H5Location::getComment", "H5Oget_comment_by_name failed");
@@ -636,7 +633,7 @@ void H5Location::reference(void* ref, const char* name, const DataSpace& dataspa
    try {
       p_reference(ref, name, dataspace.getId(), ref_type);
    }
-   catch (ReferenceException E) {
+   catch (ReferenceException& E) {
       throw ReferenceException(inMemFunc("reference"), E.getDetailMsg());
    }
 }
@@ -662,7 +659,7 @@ void H5Location::reference(void* ref, const H5std_string& name, const DataSpace&
    try {
       p_reference(ref, name.c_str(), dataspace.getId(), ref_type);
    }
-   catch (ReferenceException E) {
+   catch (ReferenceException& E) {
       throw ReferenceException(inMemFunc("reference"), E.getDetailMsg());
    }
 }
@@ -686,7 +683,7 @@ void H5Location::reference(void* ref, const char* name, H5R_type_t ref_type) con
    try {
       p_reference(ref, name, -1, ref_type);
    }
-   catch (ReferenceException E) {
+   catch (ReferenceException& E) {
       throw ReferenceException(inMemFunc("reference"), E.getDetailMsg());
    }
 }
@@ -795,7 +792,7 @@ H5G_obj_t H5Location::getObjType(void *ref, H5R_type_t ref_type) const
    try {
       return(p_get_obj_type(ref, ref_type));
    }
-   catch (ReferenceException E) {
+   catch (ReferenceException& E) {
       throw ReferenceException(inMemFunc("getObjType"), E.getDetailMsg());
    }
 }
@@ -851,7 +848,7 @@ H5O_type_t H5Location::getRefObjType(void *ref, H5R_type_t ref_type) const
    try {
       return(p_get_ref_obj_type(ref, ref_type));
    }
-   catch (ReferenceException E) {
+   catch (ReferenceException& E) {
       throw ReferenceException(inMemFunc("getRefObjType"), E.getDetailMsg());
    }
 }
@@ -917,7 +914,7 @@ DataSpace H5Location::getRegion(void *ref, H5R_type_t ref_type) const
 	f_DataSpace_setId(&dataspace, space_id);
 	return(dataspace);
    }
-   catch (DataSpaceIException E) {
+   catch (DataSpaceIException& E) {
       throw ReferenceException(inMemFunc("getRegion"), E.getDetailMsg());
    }
 }
@@ -942,7 +939,7 @@ H5Location::~H5Location() {}
 //--------------------------------------------------------------------------
 void f_Attribute_setId(Attribute* attr, hid_t new_id)
 {
-    attr->id = new_id;
+    attr->p_setId(new_id);
 }
 
 //--------------------------------------------------------------------------
@@ -957,9 +954,7 @@ void f_Attribute_setId(Attribute* attr, hid_t new_id)
 //--------------------------------------------------------------------------
 void f_DataSpace_setId(DataSpace* dspace, hid_t new_id)
 {
-    dspace->id = new_id;
+    dspace->p_setId(new_id);
 }
 
-#ifndef H5_NO_NAMESPACE
 } // end namespace
-#endif
