@@ -26,9 +26,7 @@
 #include "H5DataType.h"
 #include "H5VarLenType.h"
 
-#ifndef H5_NO_NAMESPACE
 namespace H5 {
-#endif
 
 
 //--------------------------------------------------------------------------
@@ -81,6 +79,4 @@ VarLenType::VarLenType(const DataType* base_type) : DataType()
 //--------------------------------------------------------------------------
 VarLenType::~VarLenType() {}
 
-#ifndef H5_NO_NAMESPACE
 } // end namespace
-#endif
