@@ -32,18 +32,14 @@
 #endif
 #include <string>
 
-#ifndef H5_NO_NAMESPACE
 #ifndef H5_NO_STD
     using std::cerr;
     using std::endl;
 #endif  // H5_NO_STD
-#endif
 
 #include "H5Cpp.h"	// C++ API header file
 
-#ifndef H5_NO_NAMESPACE
     using namespace H5;
-#endif
 
 #include "h5cpputil.h"	// C++ utilility header file
 
@@ -61,8 +57,9 @@ const int H5Z_FILTER_BOGUS = 305;
 
 static size_t filter_bogus(unsigned int flags, size_t cd_nelmts,
     const unsigned int *cd_values, size_t nbytes, size_t *buf_size, void **buf);
-// UNUSED variables caused warning, but taking them out caused failure.
+// H5_ATTR_UNUSED variables caused warning, but taking them out caused failure.
 
+
 /*-------------------------------------------------------------------------
  * Function:	test_create
  *
@@ -82,7 +79,7 @@ static size_t filter_bogus(unsigned int flags, size_t cd_nelmts,
 static herr_t
 test_create( H5File& file)
 {
-    SUBTEST("create, open, close");
+    SUBTEST("Create, open, close");
 
     // Setting this to NULL for cleaning up in failure situations
     DataSet *dataset = NULL;
@@ -116,7 +113,7 @@ test_create( H5File& file)
 	    // continuation here, that means no exception has been thrown
 	    throw InvalidActionException("H5File::createDataSet", "Library allowed overwrite of existing dataset");
 	}
-	catch (FileIException E)	// catching invalid creating dataset
+	catch (FileIException& E)	// catching invalid creating dataset
 	{} // do nothing, exception expected
 
 	// Open the dataset we created above and then close it.  This is one
@@ -148,7 +145,7 @@ test_create( H5File& file)
 	    // continuation here, that means no exception has been thrown
 	    throw InvalidActionException("H5File::openDataSet", "Attempted to open a non-existent dataset");
 	}
-	catch (FileIException E ) // catching creating non-existent dataset
+	catch (FileIException& E ) // catching creating non-existent dataset
 	{} // do nothing, exception expected
 
 	// Create a new dataset that uses chunked storage instead of the default
@@ -170,7 +167,7 @@ test_create( H5File& file)
 	return 0;
     }	// outer most try block
 
-    catch (InvalidActionException E)
+    catch (InvalidActionException& E)
     {
 	cerr << " FAILED" << endl;
 	cerr << "    <<<  " << E.getDetailMsg() << "  >>>" << endl << endl;
@@ -181,7 +178,7 @@ test_create( H5File& file)
 	return -1;
     }
     // catch all other exceptions
-    catch (Exception E)
+    catch (Exception& E)
     {
 	issue_fail_msg("test_create", __LINE__, __FILE__);
 
@@ -192,6 +189,7 @@ test_create( H5File& file)
     }
 }   // test_create
 
+
 /*-------------------------------------------------------------------------
  * Function:	test_simple_io
  *
@@ -214,7 +212,7 @@ static herr_t
 test_simple_io( H5File& file)
 {
 
-    SUBTEST("simple I/O");
+    SUBTEST("Simple I/O");
 
     int	points[100][200];
     int	check[100][200];
@@ -246,10 +244,10 @@ test_simple_io( H5File& file)
 	DataSet dataset (file.createDataSet (DSET_SIMPLE_IO_NAME, PredType::NATIVE_INT, space));
 
 	// Write the data to the dataset
-	dataset.write ((void*) points, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+	dataset.write(static_cast<void*>(points), PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
 
 	// Read the dataset back
-	dataset.read ((void*) check, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+	dataset.read (static_cast<void*>(check), PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
 
 	// Check that the values read are the same as the values written
 	for (i = 0; i < 100; i++)
@@ -267,7 +265,7 @@ test_simple_io( H5File& file)
     }  // end try
 
     // catch all dataset, space, plist exceptions
-    catch (Exception E)
+    catch (Exception& E)
     {
 	cerr << " FAILED" << endl;
 	cerr << "    <<<  " << E.getDetailMsg() << "  >>>" << endl << endl;
@@ -279,6 +277,7 @@ test_simple_io( H5File& file)
     }
 }   // test_simple_io
 
+
 /*-------------------------------------------------------------------------
  * Function:	test_datasize
  *
@@ -339,7 +338,7 @@ test_datasize(FileAccPropList &fapl)
     }  // end try
 
     // catch all dataset, space, plist exceptions
-    catch (Exception E)
+    catch (Exception& E)
     {
 	cerr << " FAILED" << endl;
 	cerr << "    <<<  " << E.getDetailMsg() << "  >>>" << endl << endl;
@@ -348,6 +347,7 @@ test_datasize(FileAccPropList &fapl)
     }
 }   // test_datasize
 
+
 /*-------------------------------------------------------------------------
  * Function:	test_tconv
  *
@@ -365,7 +365,7 @@ test_datasize(FileAccPropList &fapl)
  *-------------------------------------------------------------------------
  */
 static herr_t
-test_tconv( H5File& file)
+test_tconv(H5File& file)
 {
     // Prepare buffers for input/output
     char	*out=NULL, *in=NULL;
@@ -374,7 +374,7 @@ test_tconv( H5File& file)
     in = new char [4*1000000];
     //assert (in);
 
-    SUBTEST("data type conversion");
+    SUBTEST("Data type conversion");
 
     // Initialize the dataset
     for (int i = 0; i < 1000000; i++) {
@@ -395,10 +395,10 @@ test_tconv( H5File& file)
 	DataSet dataset (file.createDataSet (DSET_TCONV_NAME, PredType::STD_I32LE, space));
 
 	// Write the data to the dataset
-	dataset.write ((void*) out, PredType::STD_I32LE);
+	dataset.write (static_cast<void*>(out), PredType::STD_I32LE);
 
 	// Read data with byte order conversion
-	dataset.read ((void*) in, PredType::STD_I32BE);
+	dataset.read (static_cast<void*>(in), PredType::STD_I32BE);
 
 	// Check
 	for (int i = 0; i < 1000000; i++) {
@@ -419,7 +419,7 @@ test_tconv( H5File& file)
     }  // end try
 
     // catch all dataset and space exceptions
-    catch (Exception E)
+    catch (Exception& E)
     {
 	cerr << " FAILED" << endl;
 	cerr << "    <<<  " << E.getDetailMsg() << "  >>>" << endl << endl;
@@ -462,11 +462,12 @@ static size_t
 filter_bogus(unsigned int flags, size_t cd_nelmts,
       const unsigned int cd_values[], size_t nbytes,
       size_t *buf_size, void **buf)
-// UNUSED variables caused warning, but taking them out caused failure.
+// H5_ATTR_UNUSED variables caused warning, but taking them out caused failure.
 {
     return nbytes;
 }
 
+
 /*-------------------------------------------------------------------------
  * Function:	test_compression
  *
@@ -504,6 +505,7 @@ test_compression(H5File& file)
 	    points[i][j] = (int)n++;
 	}
     }
+
     char* tconv_buf = new char [1000];
     DataSet* dataset = NULL;
     try
@@ -539,7 +541,7 @@ test_compression(H5File& file)
 	*/
 	SUBTEST("Compression (uninitialized read)");
 
-	dataset->read ((void*) check, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+	dataset->read (static_cast<void*>(check), PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
 
 	for (i=0; i<size[0]; i++) {
 	    for (j=0; j<size[1]; j++) {
@@ -569,7 +571,7 @@ test_compression(H5File& file)
 	    }
 	}
 
-	dataset->write ((void*) points, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+	dataset->write (static_cast<void*>(points), PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
 
 	PASSED();
 
@@ -580,7 +582,7 @@ test_compression(H5File& file)
 	SUBTEST("Compression (read)");
 
 	// Read the dataset back
-	dataset->read ((void*)check, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+	dataset->read (static_cast<void*>(check), PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
 
 	// Check that the values read are the same as the values written
 	for (i = 0; i < size[0]; i++)
@@ -609,10 +611,10 @@ test_compression(H5File& file)
 	    	points[i][j] = rand ();
 	    }
 	}
-	dataset->write ((void*)points, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+	dataset->write (static_cast<void*>(points), PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
 
 	// Read the dataset back and check it
-	dataset->read ((void*)check, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+	dataset->read (static_cast<void*>(check), PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
 
 	// Check that the values read are the same as the values written
 	for (i = 0; i < size[0]; i++)
@@ -637,7 +639,7 @@ test_compression(H5File& file)
 	delete dataset;
 
 	dataset = new DataSet (file.openDataSet (DSET_COMPRESS_NAME));
-	dataset->read ((void*)check, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+	dataset->read (static_cast<void*>(check), PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
 
 	// Check that the values read are the same as the values written
 	for (i = 0; i < size[0]; i++)
@@ -667,8 +669,8 @@ test_compression(H5File& file)
 	    }
 	}
 	space1.selectHyperslab( H5S_SELECT_SET, hs_size, hs_offset );
-	dataset->write ((void*)points, PredType::NATIVE_INT, space1, space1, xfer);
-	dataset->read ((void*)check, PredType::NATIVE_INT, space1, space1, xfer);
+	dataset->write (static_cast<void*>(points), PredType::NATIVE_INT, space1, space1, xfer);
+	dataset->read (static_cast<void*>(check), PredType::NATIVE_INT, space1, space1, xfer);
 
 	// Check that the values read are the same as the values written
 	for (i=0; i<hs_size[0]; i++) {
@@ -714,8 +716,8 @@ test_compression(H5File& file)
 	DataSpace space2 (2, size, NULL);
 	dataset = new DataSet (file.createDataSet (DSET_BOGUS_NAME, PredType::NATIVE_INT, space2, dscreatplist));
 
-	dataset->write ((void*)points, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
-	dataset->read ((void*)check, PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+	dataset->write (static_cast<void*>(points), PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
+	dataset->read (static_cast<void*>(check), PredType::NATIVE_INT, DataSpace::ALL, DataSpace::ALL, xfer);
 
 	// Check that the values read are the same as the values written
 	for (i = 0; i < size[0]; i++)
@@ -738,7 +740,7 @@ test_compression(H5File& file)
     } // end try
 
     // catch all dataset, file, space, and plist exceptions
-    catch (Exception E)
+    catch (Exception& E)
     {
 	cerr << " FAILED" << endl;
 	cerr << "    <<<  " << E.getDetailMsg() << "  >>>" << endl << endl;
@@ -752,6 +754,123 @@ test_compression(H5File& file)
     }
 }   // test_compression
 
+
+/*-------------------------------------------------------------------------
+ * Function:    test_nbit_methods
+ *
+ * Purpose:     Tests setting nbit compression methods.
+ *
+ * Return:      Success:        0
+ *
+ *              Failure:        -1
+ *
+ * Programmer:	Binh-Minh Ribler
+ *		Friday, April 22, 2016
+ *
+ *-------------------------------------------------------------------------
+ */
+const H5std_string	DSET_NBIT_NAME("nbit_dataset");
+const hsize_t DIM1 = 2;
+const hsize_t DIM2 = 5;
+static herr_t test_nbit_compression(H5File& file)
+{
+    typedef struct {
+        int i;
+        char c;
+        short s;
+    } s1_t;
+
+    const hsize_t size[2] = {DIM1, DIM2};
+    const hsize_t chunk_size[2] = {DIM1, DIM2};
+    s1_t          orig_data[DIM1][DIM2];
+    s1_t          new_data[DIM1][DIM2];
+    hsize_t       i, j;
+
+    SUBTEST("N-bit compression (setup)");
+
+    try
+    {
+	// Define datatypes of members of compound datatype
+	IntType i_type(PredType::NATIVE_INT);
+	IntType c_type(PredType::NATIVE_CHAR);
+	IntType s_type(PredType::NATIVE_SHORT);
+
+	// Create a dataset compound datatype
+	CompType cmpd(sizeof(s1_t));
+	cmpd.insertMember("i", HOFFSET(s1_t, i), i_type);
+	cmpd.insertMember("c", HOFFSET(s1_t, c), c_type);
+	cmpd.insertMember("s", HOFFSET(s1_t, s), s_type);
+
+	// Create a memory compound datatype
+	CompType mem_cmpd(sizeof(s1_t));
+	mem_cmpd.insertMember("i", HOFFSET(s1_t, i), i_type);
+	mem_cmpd.insertMember("c", HOFFSET(s1_t, c), c_type);
+	mem_cmpd.insertMember("s", HOFFSET(s1_t, s), s_type);
+
+	// Set order of dataset compound datatype
+	//cmpd.setOrder(H5T_ORDER_BE); only for atomic type?
+
+	// Create the data space
+	DataSpace space(2, size);
+
+	// Use nbit filter
+	DSetCreatPropList dscreat;
+	dscreat.setChunk(2, chunk_size);
+	dscreat.setNbit();
+
+	// Create the dataset
+	DataSet dataset(file.createDataSet(DSET_NBIT_NAME, cmpd, space, dscreat));
+
+	// Initialize data, assuming size of long long >= size of member datatypes
+	for (i = 0; i < size[0]; i++)
+	    for (j = 0; j < size[1]; j++)
+	    {
+		orig_data[i][j].i = static_cast<int>(i * j);
+		orig_data[i][j].c = static_cast<char>('a' + i);
+		orig_data[i][j].s = static_cast<short>(i + j);
+
+		// Some even-numbered integer values are negative
+		if ((i*size[1]+j+1)%2 == 0) {
+		    orig_data[i][j].i = -orig_data[i][j].i;
+		    orig_data[i][j].s = static_cast<short>(-orig_data[i][j].s);
+		}
+	    }
+
+	// Write to the dataset
+	dataset.write(static_cast<void*>(orig_data), mem_cmpd);
+
+	// Read the dataset back */
+	dataset.read(static_cast<void*>(new_data), mem_cmpd);
+
+	// Check that the values read are the same as the values written.
+	for (i = 0; i < size[0]; i++)
+	    for (j = 0; j < size[1]; j++)
+	    {
+		if((new_data[i][j].i != orig_data[i][j].i) ||
+		   (new_data[i][j].c != orig_data[i][j].c) ||
+		   (new_data[i][j].s != orig_data[i][j].s))
+		{
+		    H5_FAILED();
+		    printf("    Read different values than written.\n");
+		    printf("    At index %lu,%lu\n", static_cast<unsigned long>(i), static_cast<unsigned long>(j));
+		}
+            }
+
+	PASSED();
+	return 0;
+    } // end try block
+
+    // catch all dataset, file, space, and plist exceptions
+    catch (Exception& E)
+    {
+	cerr << " FAILED" << endl;
+	cerr << "    <<<  " << E.getDetailMsg() << "  >>>" << endl << endl;
+
+	return -1;
+    }
+} // test_nbit_compression
+
+
 /*-------------------------------------------------------------------------
  * Function:	test_multiopen
  *
@@ -788,7 +907,7 @@ test_multiopen (H5File& file)
 	dcpl.setChunk (1, cur_size);
 
 	// Create a simple data space with unlimited size
-	static hsize_t	max_size[1] = {H5S_UNLIMITED};
+	hsize_t	max_size[1] = {H5S_UNLIMITED};
 	space = new DataSpace (1, cur_size, max_size);
 
 	// Create first dataset
@@ -824,7 +943,7 @@ test_multiopen (H5File& file)
     } // end try block
 
     // catch all dataset, file, space, and plist exceptions
-    catch (Exception E)
+    catch (Exception& E)
     {
 	cerr << " FAILED" << endl;
 	cerr << "    <<<  " << E.getDetailMsg() << "  >>>" << endl << endl;
@@ -836,6 +955,7 @@ test_multiopen (H5File& file)
     }
 }   // test_multiopen
 
+
 /*-------------------------------------------------------------------------
  * Function:	test_types
  *
@@ -907,7 +1027,7 @@ test_types(H5File& file)
 	} // end try block of bitfield_1
 
 	// catch exceptions thrown in try block of bitfield_1
-	catch (Exception E)
+	catch (Exception& E)
 	{
 	    cerr << " FAILED" << endl;
 	    cerr << "    <<<  " << "bitfield_1: " << E.getFuncName()
@@ -939,7 +1059,8 @@ test_types(H5File& file)
 	} // end try block of bitfield_2
 
 	// catch exceptions thrown in try block of bitfield_2
-	catch (Exception E) {
+	catch (Exception& E)
+	{
 	    cerr << " FAILED" << endl;
 	    cerr << "    <<<  " << "bitfield_2: " << E.getFuncName()
 		 << " - " << E.getDetailMsg() << "  >>>" << endl << endl;
@@ -971,7 +1092,8 @@ test_types(H5File& file)
 	} // end try block of opaque_1
 
 	// catch exceptions thrown in try block of opaque_1
-	catch (Exception E) {
+	catch (Exception& E)
+	{
 	    cerr << " FAILED" << endl;
 	    cerr << "    <<<  " << "opaque_1: " << E.getFuncName()
 		 << " - " << E.getDetailMsg() << "  >>>" << endl << endl;
@@ -1004,7 +1126,8 @@ test_types(H5File& file)
 	} //end try block of opaque_2
 
 	// catch exceptions thrown in try block of opaque_2
-	catch (Exception E) {
+	catch (Exception& E)
+	{
 	    cerr << " FAILED" << endl;
 	    cerr << "    <<<  " << "opaque_2: " << E.getFuncName()
 		 << " - " << E.getDetailMsg() << "  >>>" << endl << endl;
@@ -1019,12 +1142,13 @@ test_types(H5File& file)
 	return 0;
     } // end top try block
 
-    catch (Exception E)
+    catch (Exception& E)
     {
 	return -1;
     }
 }   // test_types
 
+
 /*-------------------------------------------------------------------------
  * Function:	test_dset
  *
@@ -1047,9 +1171,7 @@ test_types(H5File& file)
  *
  *-------------------------------------------------------------------------
  */
-#ifdef __cplusplus
 extern "C"
-#endif
 void test_dset()
 {
     hid_t	fapl_id;
@@ -1073,6 +1195,7 @@ void test_dset()
 	nerrors += test_simple_io(file) < 0 ? 1:0;
 	nerrors += test_tconv(file) < 0 ? 1:0;
 	nerrors += test_compression(file) < 0 ? 1:0;
+	nerrors += test_nbit_compression(file) < 0 ? 1:0;
 	nerrors += test_multiopen (file) < 0 ? 1:0;
 	nerrors += test_types(file) < 0 ? 1:0;
 
@@ -1084,7 +1207,7 @@ void test_dset()
 
 	nerrors += test_datasize(fapl) <0 ? 1:0;
     }
-    catch (Exception E)
+    catch (Exception& E)
     {
 	test_report(nerrors, H5std_string(" Dataset"));
     }
@@ -1106,9 +1229,7 @@ void test_dset()
  *
  *-------------------------------------------------------------------------
  */
-#ifdef __cplusplus
 extern "C"
-#endif
 void cleanup_dsets()
 {
     HDremove(FILE1.c_str());
