@@ -28,18 +28,13 @@
 #endif
 #include <string>
 
-#ifndef H5_NO_NAMESPACE
 #ifndef H5_NO_STD
     using std::cerr;
     using std::endl;
 #endif  // H5_NO_STD
-#endif
 
 #include "H5Cpp.h"      // C++ API header file
-
-#ifndef H5_NO_NAMESPACE
-    using namespace H5;
-#endif
+using namespace H5;
 
 #include "h5cpputil.h"  // C++ utilility header file
 
@@ -958,9 +953,7 @@ static void test_vl_rewrite()
  *
  *-------------------------------------------------------------------------
  */
-#ifdef __cplusplus
 extern "C"
-#endif
 void test_vlstrings()
 {
     // Output message about test being performed
@@ -1000,9 +993,7 @@ void test_vlstrings()
  *
  *-------------------------------------------------------------------------
  */
-#ifdef __cplusplus
 extern "C"
-#endif
 void cleanup_vlstrings()
 {
     HDremove(FILENAME.c_str());
